tinyMCE.addI18n('fr.xhtmlxtras_dlg',{
attribute_label_title:"Titre",
attribute_label_id:"ID",
attribute_label_class:"Classe",
attribute_label_style:"Style",
attribute_label_cite:"Citation",
attribute_label_datetime:"Date / heure",
attribute_label_langdir:"Sens de lecture",
attribute_option_ltr:"De gauche \u00E0 droite",
attribute_option_rtl:"De droite \u00E0 gauche",
attribute_label_langcode:"Langue",
attribute_label_tabindex:"TabIndex",
attribute_label_accesskey:"Accesskey",
attribute_events_tab:"\u00C9v\u00E8nements",
attribute_attrib_tab:"Attributs",
general_tab:"G\u00E9n\u00E9ral",
attrib_tab:"Attributs",
events_tab:"\u00C9v\u00E9nements",
fieldset_general_tab:"Param\u00E8tres g\u00E9n\u00E9raux",
fieldset_attrib_tab:"Attributs",
fieldset_events_tab:"\u00C9v\u00E9nements",
title_ins_element:"Insertion",
title_del_element:"Suppression",
title_acronym_element:"Acronyme",
title_abbr_element:"Abr\u00E9viation",
title_cite_element:"Citation",
remove:"Enlever",
insert_date:"Ins\u00E9rer la date et l'heure actuelles",
option_ltr:"De gauche \u00E0 droite",
option_rtl:"De droite \u00E0 gauche",
attribs_title:"Ins\u00E9rer / \u00E9diter les attributs"
});
